@@ -1,16 +1,17 @@
 /*
- * $Id: Image.java 5993 2013-09-06 21:13:00Z rafhens $
+ * $Id: Image.java 6193 2014-01-29 15:01:04Z michaeldemey $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -43,17 +44,11 @@
  */
 package com.itextpdf.text;
 
-import java.io.IOException;
-import java.io.InputStream;
-import java.lang.reflect.Constructor;
-import java.net.MalformedURLException;
-import java.net.URL;
-import java.util.HashMap;
-
 import com.itextpdf.awt.PdfGraphics2D;
 import com.itextpdf.text.api.Indentable;
 import com.itextpdf.text.api.Spaceable;
 import com.itextpdf.text.error_messages.MessageLocalization;
+import com.itextpdf.text.io.RandomAccessSourceFactory;
 import com.itextpdf.text.pdf.ICC_Profile;
 import com.itextpdf.text.pdf.PRIndirectReference;
 import com.itextpdf.text.pdf.PdfArray;
@@ -79,6 +74,13 @@ import com.itextpdf.text.pdf.codec.TiffImage;
 import com.itextpdf.text.pdf.interfaces.IAccessibleElement;
 import com.itextpdf.text.pdf.interfaces.IAlternateDescription;
 
+import java.io.IOException;
+import java.io.InputStream;
+import java.lang.reflect.Constructor;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.HashMap;
+
 /**
  * An <CODE>Image</CODE> is the representation of a graphic element (JPEG, PNG
  * or GIF) that has to be inserted into the document
@@ -250,9 +252,11 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 	 * @throws MalformedURLException
 	 * @throws IOException
 	 */
-	public static Image getInstance(final URL url, boolean handleIncorrectImage) throws BadElementException,
+	public static Image getInstance(final URL url, boolean recoverFromImageError) throws BadElementException,
 			MalformedURLException, IOException {
 		InputStream is = null;
+        RandomAccessSourceFactory randomAccessSourceFactory = new RandomAccessSourceFactory();
+
 		try {
 			is = url.openStream();
 			int c1 = is.read();
@@ -298,13 +302,22 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 					if (url.getProtocol().equals("file")) {
 						String file = url.getFile();
                         file = Utilities.unEscapeURL(file);
-						ra = new RandomAccessFileOrArray(file);
+						ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createBestSource(file));
 					} else
-						ra = new RandomAccessFileOrArray(url);
-					Image img = TiffImage.getTiffImage(ra, handleIncorrectImage, 1);
+						ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createSource(url));
+					Image img = TiffImage.getTiffImage(ra, 1);
 					img.url = url;
 					return img;
-				} finally {
+				} catch (RuntimeException e ) {
+                    if ( recoverFromImageError ) {
+                        // reruns the getTiffImage() with several error recovering workarounds in place
+                        // not guaranteed to work with every TIFF
+                        Image img = TiffImage.getTiffImage(ra, recoverFromImageError, 1);
+                        img.url = url;
+                        return img;
+                    }
+                    throw e;
+                } finally {
 					if (ra != null)
 						ra.close();
 				}
@@ -317,9 +330,9 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 					if (url.getProtocol().equals("file")) {
 						String file = url.getFile();
 						file = Utilities.unEscapeURL(file);
-			            ra = new RandomAccessFileOrArray(file);
+			            ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createBestSource(file));
 					} else
-						ra = new RandomAccessFileOrArray(url);
+						ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createSource(url));
 					Image img = JBIG2Image.getJbig2Image(ra, 1);
 					img.url = url;
 					return img;
@@ -352,8 +365,8 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 		return getInstance(Utilities.toURL(filename));
 	}
     
-    public static Image getInstance(final String filename, boolean handleIncorrectImage) throws IOException, BadElementException {
-        return getInstance(Utilities.toURL(filename), handleIncorrectImage);
+    public static Image getInstance(final String filename, boolean recoverFromImageError) throws IOException, BadElementException {
+        return getInstance(Utilities.toURL(filename), recoverFromImageError);
     }
 
 
@@ -372,9 +385,10 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 	 * @throws MalformedURLException
 	 * @throws IOException
 	 */
-	public static Image getInstance(final byte imgb[], boolean handleIncorrectImage) throws BadElementException,
+	public static Image getInstance(final byte imgb[], boolean recoverFromImageError) throws BadElementException,
 			MalformedURLException, IOException {
 		InputStream is = null;
+        RandomAccessSourceFactory randomAccessSourceFactory = new RandomAccessSourceFactory();
 		try {
 			is = new java.io.ByteArrayInputStream(imgb);
 			int c1 = is.read();
@@ -411,12 +425,22 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 					|| c1 == 'I' && c2 == 'I' && c3 == 42 && c4 == 0) {
 				RandomAccessFileOrArray ra = null;
 				try {
-					ra = new RandomAccessFileOrArray(imgb);
-					Image img = TiffImage.getTiffImage(ra, 1, handleIncorrectImage);
+					ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createSource(imgb));
+					Image img = TiffImage.getTiffImage(ra, 1);
                     if (img.getOriginalData() == null)
                         img.setOriginalData(imgb);
 					return img;
-				} finally {
+				} catch ( RuntimeException e ) {
+                    if ( recoverFromImageError ) {
+                        // reruns the getTiffImage() with several error recovering workarounds in place
+                        // not guaranteed to work with every TIFF
+                        Image img = TiffImage.getTiffImage(ra, recoverFromImageError, 1);
+                        if (img.getOriginalData() == null)
+                            img.setOriginalData(imgb);
+                        return img;
+                    }
+                    throw e;
+                } finally {
 					if (ra != null)
 						ra.close();
 				}
@@ -429,20 +453,14 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 				int c6 = is.read();
 				int c7 = is.read();
 				int c8 = is.read();
+                is.close();
 				if ( c5 == '\r' && c6 == '\n' && c7 == 0x1a && c8 == '\n' ) {
-					int file_header_flags = is.read();
-					// TODO number of pages never read, can be removed?
-					int number_of_pages = -1;
-					if ( (file_header_flags & 0x2) == 0x2 ) {
-						number_of_pages = is.read() << 24 | is.read() << 16 | is.read() << 8 | is.read();
-					}
-					is.close();
 					// a jbig2 file with a file header.  the header is the only way we know here.
 					// embedded jbig2s don't have a header, have to create them by explicit use of Jbig2Image?
 					// nkerr, 2008-12-05  see also the getInstance(URL)
 					RandomAccessFileOrArray ra = null;
 					try {
-						ra = new RandomAccessFileOrArray(imgb);
+						ra = new RandomAccessFileOrArray(randomAccessSourceFactory.createSource(imgb));
 						Image img = JBIG2Image.getJbig2Image(ra, 1);
 						if (img.getOriginalData() == null)
 							img.setOriginalData(imgb);
@@ -493,8 +511,7 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
 	 * @since	2.1.5
 	 */
 	public static Image getInstance(final int width, final int height, final byte[] data, final byte[] globals) {
-		Image img = new ImgJBIG2(width, height, data, globals);
-		return img;
+		return new ImgJBIG2(width, height, data, globals);
 	}
 
 	/**
@@ -1945,6 +1962,10 @@ public abstract class Image extends Rectangle implements Indentable, Spaceable,
         this.id = id;
     }
 
+    public boolean isInline() {
+        return true;
+    }
+
     // AWT related methods (remove this if you port to Android / GAE)
 
 	/**
