@@ -1,16 +1,17 @@
 /*
- * $Id: ListLabel.java 6019 2013-09-25 10:44:24Z blowagie $
+ * $Id: ListLabel.java 6192 2014-01-29 14:37:53Z eugenemark $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Alexander Chingarev, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -49,7 +50,6 @@ public class ListLabel extends ListBody {
 
     protected PdfName role = PdfName.LBL;
     protected float indentation = 0;
-    protected boolean tagLabelContent = true;
 
     protected ListLabel(final ListItem parentItem) {
         super(parentItem);
@@ -89,12 +89,16 @@ public class ListLabel extends ListBody {
      * &lt;/LI&gt;
      * @return
      */
+    @Deprecated
     public boolean getTagLabelContent() {
-        return tagLabelContent;
+        return false;
     }
 
-    public void setTagLabelContent(boolean tagLabelContent) {
-        this.tagLabelContent = tagLabelContent;
-    }
+    @Deprecated
+    public void setTagLabelContent(boolean tagLabelContent) {}
 
+    @Override
+    public boolean isInline() {
+        return true;    //To change body of overridden methods use File | Settings | File Templates.
+    }
 }
