@@ -1,5 +1,5 @@
 /*
- * $Id: HtmlTags.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: HtmlTags.java 6457 2014-07-09 14:04:16Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -47,7 +47,9 @@ package com.itextpdf.text.html;
 /**
  * Static final values of supported HTML tags and attributes.
  * @since 5.0.6
+ * @deprecated since 5.5.2
  */
+@Deprecated
 public class HtmlTags {
 
 	// tag names
