@@ -1,5 +1,5 @@
 /*
- * $Id: HtmlUtilities.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: HtmlUtilities.java 6457 2014-07-09 14:04:16Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -53,8 +53,9 @@ import com.itextpdf.text.Element;
 /**
  * A class that contains some utilities to parse HTML attributes and content.
  * @since 5.0.6 (some of these methods used to be in the Markup class)
+ * @deprecated since 5.5.2
  */
-
+@Deprecated
 public class HtmlUtilities {
 
 	/**
