@@ -1,5 +1,5 @@
 /*
- * $Id: ElementFactory.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: ElementFactory.java 6457 2014-07-09 14:04:16Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -73,7 +73,9 @@ import com.itextpdf.text.pdf.draw.LineSeparator;
  * @author blowagie
  * @author psoares
  * @since 5.0.6 (renamed)
+ * @deprecated since 5.5.2
  */
+@Deprecated
 public class ElementFactory {
 
 
