@@ -1,5 +1,5 @@
 /*
- * $Id: ImageStore.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: ImageStore.java 6457 2014-07-09 14:04:16Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -50,7 +50,9 @@ import com.itextpdf.text.Image;
 
 /**
  * @since 5.0.6
+ * @deprecated since 5.5.2
  */
+@Deprecated
 public class ImageStore extends HashMap<String, Image> {
 
 	/** Serial version UID. */
