@@ -1,5 +1,5 @@
 /*
- * $Id: TableWrapper.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: TableWrapper.java 6457 2014-07-09 14:04:16Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -63,7 +63,10 @@ import com.itextpdf.text.pdf.PdfPTable;
  * to put on the HTMLWorker stack.
  * @author  psoares
  * @since 5.0.6 (renamed)
+ * @deprecated since 5.5.2
  */
+@Deprecated
+
 public class TableWrapper implements Element {
 	/**
 	 * The styles that need to be applied to the table
