@@ -1,16 +1,17 @@
 /*
- * $Id: ColumnText.java 6020 2013-09-25 10:47:31Z blowagie $
+ * $Id: ColumnText.java 6192 2014-01-29 14:37:53Z eugenemark $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -1006,9 +1007,7 @@ public class ColumnText {
                         ListLabel lbl = ((ListItem)elementToGo).getListLabel();
                         canvas.openMCBlock(lbl);
                         Chunk symbol = new Chunk(((ListItem)elementToGo).getListSymbol());
-                        if (!lbl.getTagLabelContent()) {
-                            symbol.setRole(null);
-                        }
+                        symbol.setRole(null);
                         ColumnText.showTextAligned(canvas, Element.ALIGN_LEFT, new Phrase(symbol), leftX + lbl.getIndentation(), firstLineY, 0);
                         canvas.closeMCBlock(lbl);
                     }
