@@ -1,5 +1,5 @@
 /*
- * $Id: FdfWriter.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: FdfWriter.java 6404 2014-05-26 15:43:23Z pavel-alay $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -44,6 +44,13 @@
  */
 package com.itextpdf.text.pdf;
 
+import com.itextpdf.text.DocWriter;
+import com.itextpdf.text.ExceptionConverter;
+import com.itextpdf.text.Image;
+import com.itextpdf.text.log.Counter;
+import com.itextpdf.text.log.CounterFactory;
+import com.itextpdf.text.pdf.AcroFields.Item;
+
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.ArrayList;
@@ -51,32 +58,46 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.StringTokenizer;
 
-import com.itextpdf.text.DocWriter;
-import com.itextpdf.text.log.Counter;
-import com.itextpdf.text.log.CounterFactory;
-import com.itextpdf.text.pdf.AcroFields.Item;
-
 /** Writes an FDF form.
  * @author Paulo Soares
  */
 public class FdfWriter {
     private static final byte[] HEADER_FDF = DocWriter.getISOBytes("%FDF-1.4\n%\u00e2\u00e3\u00cf\u00d3\n");
     HashMap<String, Object> fields = new HashMap<String, Object>();
+    Wrt wrt = null;
 
     /** The PDF file associated with the FDF. */
     private String file;
+    private String statusMessage;
 
     /** Creates a new FdfWriter. */
     public FdfWriter() {
     }
 
+    public FdfWriter(OutputStream os) throws IOException {
+        wrt = new Wrt(os, this);
+    }
+
     /** Writes the content to a stream.
      * @param os the stream
      * @throws IOException on error
      */
     public void writeTo(OutputStream os) throws IOException {
-        Wrt wrt = new Wrt(os, this);
-        wrt.writeTo();
+        if (wrt == null)
+            wrt = new Wrt(os, this);
+        wrt.write();
+    }
+
+    public void write() throws IOException {
+        wrt.write();
+    }
+
+    public String getStatusMessage() {
+        return statusMessage;
+    }
+
+    public void setStatusMessage(String statusMessage) {
+        this.statusMessage = statusMessage;
     }
 
     @SuppressWarnings("unchecked")
@@ -247,6 +268,55 @@ public class FdfWriter {
     	return setField(field, action);
     }
 
+    public boolean setFieldAsTemplate(String field, PdfTemplate template) {
+        try {
+            PdfDictionary d = new PdfDictionary();
+            if (template instanceof PdfImportedPage)
+                d.put(PdfName.N, template.getIndirectReference());
+            else {
+                PdfStream str = template.getFormXObject(PdfStream.NO_COMPRESSION);
+                PdfIndirectReference ref = wrt.addToBody(str).getIndirectReference();
+                d.put(PdfName.N, ref);
+            }
+            return setField(field, d);
+        } catch (Exception e) {
+            throw new ExceptionConverter(e);
+        }
+    }
+
+    public boolean setFieldAsImage(String field, Image image) {
+        try {
+            if (Float.isNaN(image.getAbsoluteX()))
+                image.setAbsolutePosition(0, image.getAbsoluteY());
+            if (Float.isNaN(image.getAbsoluteY()))
+                image.setAbsolutePosition(image.getAbsoluteY(), 0);
+            PdfTemplate tmpl = PdfTemplate.createTemplate(wrt, image.getWidth(), image.getHeight());
+            tmpl.addImage(image);
+            PdfStream str = tmpl.getFormXObject(PdfStream.NO_COMPRESSION);
+            PdfIndirectReference ref = wrt.addToBody(str).getIndirectReference();
+            PdfDictionary d = new PdfDictionary();
+            d.put(PdfName.N, ref);
+            return setField(field, d);
+        } catch (Exception de) {
+            throw new ExceptionConverter(de);
+        }
+    }
+
+    public boolean setFieldAsJavascript(String field, PdfName jsTrigName, String js) {
+        PdfAnnotation dict = new PdfAnnotation(wrt, null);
+        PdfAction javascript = PdfAction.javaScript(js, wrt);
+        dict.put(jsTrigName, javascript);
+        return setField(field, dict);
+    }
+
+    public PdfImportedPage getImportedPage(PdfReader reader, int pageNumber) {
+        return wrt.getImportedPage(reader, pageNumber);
+    }
+
+    public PdfTemplate createTemplate(float width, float height) {
+        return PdfTemplate.createTemplate(wrt, width, height);
+    }
+
     /** Sets all the fields from this <CODE>FdfReader</CODE>
      * @param fdf the <CODE>FdfReader</CODE>
      */
@@ -316,11 +386,18 @@ public class FdfWriter {
             body = new PdfBody(this);
         }
 
-        void writeTo() throws IOException {
+        void write() throws IOException {
+            for (PdfReaderInstance element : readerInstances.values()) {
+                currentPdfReaderInstance= element;
+                currentPdfReaderInstance.writeAllPages();
+            }
+
             PdfDictionary dic = new PdfDictionary();
             dic.put(PdfName.FIELDS, calculate(fdf.fields));
             if (fdf.file != null)
                 dic.put(PdfName.F, new PdfString(fdf.file, PdfObject.TEXT_UNICODE));
+            if (fdf.statusMessage != null && fdf.statusMessage.trim().length() != 0)
+                dic.put(PdfName.STATUS, new PdfString(fdf.statusMessage));
             PdfDictionary fd = new PdfDictionary();
             fd.put(PdfName.FDF, dic);
             PdfIndirectReference ref = addToBody(fd).getIndirectReference();
@@ -343,11 +420,13 @@ public class FdfWriter {
                 dic.put(PdfName.T, new PdfString(key, PdfObject.TEXT_UNICODE));
                 if (v instanceof HashMap) {
                     dic.put(PdfName.KIDS, calculate((HashMap<String, Object>)v));
-                }
-                else if(v instanceof PdfAction) {	// (plaflamme)
+                } else if(v instanceof PdfAction) {	// (plaflamme)
                    	dic.put(PdfName.A, (PdfAction)v);
-                }
-                else {
+                } else if (v instanceof PdfAnnotation) {
+                    dic.put(PdfName.AA, (PdfAnnotation)v);
+                } else if (v instanceof PdfDictionary && ((PdfDictionary)v).size() == 1 && ((PdfDictionary)v).contains(PdfName.N)) {
+                    dic.put(PdfName.AP, (PdfDictionary)v);
+                } else {
                     dic.put(PdfName.V, (PdfObject)v);
                 }
                 ar.add(dic);
