@@ -1,5 +1,5 @@
 /*
- * $Id: PdfAnnotation.java 6154 2014-01-23 10:47:13Z pavel-alay $
+ * $Id: PdfAnnotation.java 6410 2014-05-29 13:05:23Z rafhens $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -44,25 +44,27 @@
  */
 package com.itextpdf.text.pdf;
 
+import com.itextpdf.awt.geom.AffineTransform;
+import com.itextpdf.text.AccessibleElementId;
+import com.itextpdf.text.BaseColor;
+import com.itextpdf.text.Rectangle;
+import com.itextpdf.text.error_messages.MessageLocalization;
+import com.itextpdf.text.pdf.interfaces.IAccessibleElement;
+import com.itextpdf.text.pdf.internal.PdfIsoKeys;
+
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 
-import com.itextpdf.awt.geom.AffineTransform;
-import com.itextpdf.text.BaseColor;
-import com.itextpdf.text.Rectangle;
-import com.itextpdf.text.error_messages.MessageLocalization;
-import com.itextpdf.text.pdf.internal.PdfIsoKeys;
-
 /**
  * A <CODE>PdfAnnotation</CODE> is a note that is associated with a page.
  *
  * @see		PdfDictionary
  */
 
-public class PdfAnnotation extends PdfDictionary {
+public class PdfAnnotation extends PdfDictionary implements IAccessibleElement {
     /** highlight attributename */
     public static final PdfName HIGHLIGHT_NONE = PdfName.N;
     /** highlight attributename */
@@ -91,6 +93,8 @@ public class PdfAnnotation extends PdfDictionary {
     public static final int FLAGS_LOCKED = 128;
     /** flagvalue */
     public static final int FLAGS_TOGGLENOVIEW = 256;
+    /** flagvalue PDF 1.7*/
+    public static final int FLAGS_LOCKEDCONTENTS = 512;
     /** appearance attributename */
     public static final PdfName APPEARANCE_NORMAL = PdfName.N;
     /** appearance attributename */
@@ -145,6 +149,10 @@ public class PdfAnnotation extends PdfDictionary {
     /** Holds value of property placeInPage. */
     private int placeInPage = -1;
 
+    protected PdfName role = null;
+    protected HashMap<PdfName, PdfObject> accessibleAttributes = null;
+    private AccessibleElementId id = null;
+
     // constructors
     public PdfAnnotation(PdfWriter writer, Rectangle rect) {
         this.writer = writer;
@@ -296,7 +304,7 @@ public class PdfAnnotation extends PdfDictionary {
      */
     public static PdfAnnotation createLink(PdfWriter writer, Rectangle rect, PdfName highlight, String namedDestination) {
         PdfAnnotation annot = createLink(writer, rect, highlight);
-        annot.put(PdfName.DEST, new PdfString(namedDestination));
+        annot.put(PdfName.DEST, new PdfString(namedDestination, PdfObject.TEXT_UNICODE));
         return annot;
     }
 
@@ -855,6 +863,7 @@ public class PdfAnnotation extends PdfDictionary {
     	HashMap<PdfName, PdfObject> parameters = new HashMap<PdfName, PdfObject>();
     	PdfArray destination = null;
     	int newPage=0;
+        PdfArray rect;
 
     	PdfImportedLink(PdfDictionary annotation) {
     		parameters.putAll(annotation.hashMap);
@@ -871,8 +880,18 @@ public class PdfAnnotation extends PdfDictionary {
     		lly = rc.getAsNumber(1).floatValue();
         	urx = rc.getAsNumber(2).floatValue();
     		ury = rc.getAsNumber(3).floatValue();
+
+            rect = new PdfArray(rc);
     	}
 
+        public Map<PdfName, PdfObject> getParameters() {
+            return new HashMap<PdfName, PdfObject>(parameters);
+        }
+
+        public PdfArray getRect() {
+            return new PdfArray(rect);
+        }
+
     	public boolean isInternal() {
     		return destination != null;
     	}
@@ -981,4 +1000,42 @@ public class PdfAnnotation extends PdfDictionary {
         super.toPdf(writer, os);
     }
 
+    public PdfObject getAccessibleAttribute(final PdfName key) {
+        if (accessibleAttributes != null)
+            return accessibleAttributes.get(key);
+        else
+            return null;
+    }
+
+    public void setAccessibleAttribute(final PdfName key, final PdfObject value) {
+        if (accessibleAttributes == null)
+            accessibleAttributes = new HashMap<PdfName, PdfObject>();
+        accessibleAttributes.put(key, value);
+    }
+
+    public HashMap<PdfName, PdfObject> getAccessibleAttributes() {
+        return accessibleAttributes;
+    }
+
+    public PdfName getRole() {
+        return role;
+    }
+
+    public void setRole(final PdfName role) {
+        this.role = role;
+    }
+
+    public AccessibleElementId getId() {
+        if (id == null)
+            id = new AccessibleElementId();
+        return id;
+    }
+
+    public void setId(final AccessibleElementId id) {
+        this.id = id;
+    }
+
+    public boolean isInline() {
+        return false;
+    }
 }
