@@ -1,5 +1,5 @@
 /*
- * $Id: PdfCopy.java 6212 2014-02-06 09:08:20Z michaeldemey $
+ * $Id: PdfCopy.java 6495 2014-08-19 09:42:56Z michaeldemey $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -115,7 +115,7 @@ public class PdfCopy extends PdfWriter {
     //for correct update of kids in StructTreeRootController
     protected boolean updateRootKids = false;
 
-    static private PdfName annotId = new PdfName("iTextAnnotId");
+    static private final PdfName annotId = new PdfName("iTextAnnotId");
     static private int annotIdCnt = 0;
 
     protected boolean mergeFields = false;
@@ -136,13 +136,15 @@ public class PdfCopy extends PdfWriter {
     private static final PdfName iTextTag = new PdfName("_iTextTag_");
     private static final Integer zero = Integer.valueOf(0);
     private HashSet<Object> mergedRadioButtons = new HashSet<Object>();
-    private HashMap<Object, PdfObject> mergedTextFields = new HashMap<Object, PdfObject>();
+    private HashMap<Object, PdfString> mergedTextFields = new HashMap<Object, PdfString>();
 
+    private HashSet<PdfReader> readersWithImportedStructureTreeRootKids = new HashSet<PdfReader>();
 
     protected static class ImportedPage {
         int pageNumber;
         PdfReader reader;
         PdfArray mergedFields;
+        PdfIndirectReference annotsIndirectReference;
 
         ImportedPage(PdfReader reader, int pageNumber, boolean keepFields) {
             this.pageNumber = pageNumber;
@@ -319,11 +321,20 @@ public class PdfCopy extends PdfWriter {
         ImportedPage lastPage = importedPages.get(importedPages.size() - 1);
         boolean equalReader = lastPage.reader.equals(newPage.reader);
         //reader exist, correct order;
-        if (equalReader && newPage.pageNumber > lastPage.pageNumber) return 0;
+        if (equalReader && newPage.pageNumber > lastPage.pageNumber) {
+            if (readersWithImportedStructureTreeRootKids.contains(newPage.reader))
+                return 0;
+            else
+                return 1;
+        }
         //reader exist, incorrect order;
         return -1;
     }
 
+    protected void structureTreeRootKidsForReaderImported(PdfReader reader) {
+        readersWithImportedStructureTreeRootKids.add(reader);
+    }
+
     protected void fixStructureTreeRoot(HashSet<RefKey> activeKeys, HashSet<PdfName> activeClassMaps) {
         HashMap<PdfName, PdfObject> newClassMap = new HashMap<PdfName, PdfObject>(activeClassMaps.size());
         for (PdfName key: activeClassMaps) {
@@ -347,7 +358,7 @@ public class PdfCopy extends PdfWriter {
         if (currentPdfReaderInstance != null) {
             if (currentPdfReaderInstance.getReader() != reader) {
 
-// TODO: Removed - the user should be responsible for closing all PdfReaders.  But, this could cause a lot of memory leaks in code out there that hasn't been properly closing things - maybe add a finalizer to PdfReader that calls PdfReader#close() ??
+//  TODO: Removed - the user should be responsible for closing all PdfReaders.  But, this could cause a lot of memory leaks in code out there that hasn't been properly closing things - maybe add a finalizer to PdfReader that calls PdfReader#close() ??
 //             	  try {
 //                    currentPdfReaderInstance.getReader().close();
 //                    currentPdfReaderInstance.getReaderFile().close();
@@ -650,9 +661,15 @@ public class PdfCopy extends PdfWriter {
         if (tagged)
             structTreeRootReference = (PRIndirectReference)reader.getCatalog().get(PdfName.STRUCTTREEROOT);
         PdfDictionary newPage = copyDictionary(thePage);
+        if (mergeFields) {
+            ImportedPage importedPage = importedPages.get(importedPages.size() - 1);
+            importedPage.annotsIndirectReference = body.getPdfIndirectReference();
+            newPage.put(PdfName.ANNOTS, importedPage.annotsIndirectReference);
+        }
         root.addPage(newPage);
         iPage.setCopied();
         ++currentPageNumber;
+        pdf.setPageCount(currentPageNumber);
         structTreeRootReference = null;
     }
 
@@ -673,6 +690,7 @@ public class PdfCopy extends PdfWriter {
     	page.put(PdfName.TABS, getTabs());
     	root.addPage(page);
     	++currentPageNumber;
+        pdf.setPageCount(currentPageNumber);
     }
 
     public void addDocument(PdfReader reader, List<Integer> pagesToKeep) throws DocumentException, IOException {
@@ -683,6 +701,79 @@ public class PdfCopy extends PdfWriter {
         addDocument(reader);
     }
 
+    /**
+     * Copy document fields to a destination document.
+     * @param reader a document where fields are copied from.
+     * @throws DocumentException
+     * @throws IOException
+     */
+    public void copyDocumentFields(PdfReader reader) throws DocumentException, IOException {
+        if (!document.isOpen()) {
+            throw new DocumentException(MessageLocalization.getComposedMessage("the.document.is.not.open.yet.you.can.only.add.meta.information"));
+        }
+
+        if (indirectMap.containsKey(reader)) {
+            throw new IllegalArgumentException(MessageLocalization.getComposedMessage("document.1.has.already.been.added", reader.toString()));
+        }
+
+        if (!reader.isOpenedWithFullPermissions())
+            throw new BadPasswordException(MessageLocalization.getComposedMessage("pdfreader.not.opened.with.owner.password"));
+
+        if (!mergeFields)
+            throw new IllegalArgumentException(MessageLocalization.getComposedMessage("1.method.can.be.only.used.in.mergeFields.mode.please.use.addDocument", "copyDocumentFields"));
+
+        indirects = new HashMap<RefKey, IndirectReferences>();
+        indirectMap.put(reader, indirects);
+
+        reader.consolidateNamedDestinations();
+        reader.shuffleSubsetNames();
+        if (tagged && PdfStructTreeController.checkTagged(reader)) {
+            structTreeRootReference = (PRIndirectReference)reader.getCatalog().get(PdfName.STRUCTTREEROOT);
+            if (structTreeController != null) {
+                if (reader != structTreeController.reader)
+                    structTreeController.setReader(reader);
+            } else {
+                structTreeController = new PdfStructTreeController(reader, this);
+            }
+        }
+
+        List<PdfObject> annotationsToBeCopied = new ArrayList<PdfObject>();
+
+        for (int i = 1; i <= reader.getNumberOfPages(); i++) {
+            PdfDictionary page = reader.getPageNRelease(i);
+            if (page != null && page.contains(PdfName.ANNOTS)) {
+                PdfArray annots = page.getAsArray(PdfName.ANNOTS);
+                if (annots != null && annots.size() > 0) {
+                    if (importedPages.size() < i)
+                        throw new DocumentException(MessageLocalization.getComposedMessage("there.are.not.enough.imported.pages.for.copied.fields"));
+                    indirectMap.get(reader).put(new RefKey(reader.pageRefs.getPageOrigRef(i)), new IndirectReferences(pageReferences.get(i - 1)));
+                    for (int j = 0; j < annots.size(); j++) {
+                        PdfDictionary annot = annots.getAsDict(j);
+                        if (annot != null) {
+                            annot.put(annotId, new PdfNumber(++annotIdCnt));
+                            annotationsToBeCopied.add(annots.getPdfObject(j));
+                        }
+                    }
+                }
+            }
+        }
+
+        for (PdfObject annot : annotationsToBeCopied) {
+            copyObject(annot);
+        }
+
+        if (tagged && structTreeController != null)
+            structTreeController.attachStructTreeRootKids(null);
+
+        AcroFields acro = reader.getAcroFields();
+        boolean needapp = !acro.isGenerateAppearances();
+        if (needapp)
+            needAppearances = true;
+        fields.add(acro);
+        updateCalculationOrder(reader);
+        structTreeRootReference = null;
+    }
+
     public void addDocument(PdfReader reader) throws DocumentException, IOException {
         if ( ! document.isOpen() ) {
             throw new DocumentException(MessageLocalization.getComposedMessage("the.document.is.not.open.yet.you.can.only.add.meta.information"));
@@ -714,7 +805,7 @@ public class PdfCopy extends PdfWriter {
             boolean needapp = !acro.isGenerateAppearances();
             if (needapp)
                 needAppearances = true;
-            fields.add(reader.getAcroFields());
+            fields.add(acro);
             updateCalculationOrder(reader);
         }
         boolean tagged = this.tagged && PdfStructTreeController.checkTagged(reader);
@@ -763,14 +854,12 @@ public class PdfCopy extends PdfWriter {
     }
 
     @Override
-    public PdfIndirectObject addToBody(final PdfObject object) throws IOException {
-        PdfIndirectObject iobj = super.addToBody(object);
+    protected void cacheObject(PdfIndirectObject iobj) {
         if ((tagged || mergeFields) && indirectObjects != null) {
             savedObjects.add(iobj);
             RefKey key = new RefKey(iobj.number, iobj.generation);
             if (!indirectObjects.containsKey(key)) indirectObjects.put(key, iobj);
         }
-        return iobj;
     }
 
     @Override
@@ -785,11 +874,29 @@ public class PdfCopy extends PdfWriter {
     protected void flushAcroFields() throws IOException, BadPdfFormatException {
         if (mergeFields) {
             try {
+                //save annotations that appear just at page level (comments, popups)
+                for (ImportedPage page : importedPages) {
+                    PdfDictionary pageDict = page.reader.getPageN(page.pageNumber);
+                    if (pageDict != null) {
+                        PdfArray pageFields = pageDict.getAsArray(PdfName.ANNOTS);
+                        if (pageFields == null || pageFields.size() == 0)
+                            continue;
+                        for (AcroFields.Item items: page.reader.getAcroFields().getFields().values()) {
+                            for(PdfIndirectReference ref: items.widget_refs) {
+                                pageFields.arrayList.remove(ref);
+                            }
+                        }
+                        for (PdfObject ref: pageFields.arrayList)
+                            page.mergedFields.add(copyObject(ref));
+                    }
+                }
+                //ok, remove old fields and build create new one
                 for (PdfReader reader : indirectMap.keySet()) {
                     reader.removeFields();
                 }
                 mergeFields();
                 createAcroForms();
+
             } catch (ClassCastException ex) {
             } finally {
                 if (!tagged)
@@ -1041,13 +1148,16 @@ public class PdfCopy extends PdfWriter {
             indirectObjects.remove(new RefKey(iobj.number, iobj.generation));
         HashSet<RefKey> inactives = new HashSet<RefKey>();
         for(Map.Entry<RefKey, PdfIndirectObject> entry: indirectObjects.entrySet()) {
-            if (entry.getValue() != null) writeObjectToBody(entry.getValue());
-            else inactives.add(entry.getKey());
+            if (entry.getValue() != null)
+                writeObjectToBody(entry.getValue());
+            else
+                inactives.add(entry.getKey());
         }
         ArrayList<PdfBody.PdfCrossReference> pdfCrossReferences = new ArrayList<PdfBody.PdfCrossReference>(body.xrefs);
         for (PdfBody.PdfCrossReference cr : pdfCrossReferences) {
             RefKey key = new RefKey(cr.getRefnum(), 0);
-            if (inactives.contains(key)) body.xrefs.remove(cr);
+            if (inactives.contains(key))
+                body.xrefs.remove(cr);
         }
         indirectObjects = null;
     }
@@ -1098,9 +1208,10 @@ public class PdfCopy extends PdfWriter {
             PdfArray array = (PdfArray)obj;
             for (int i = 0; i < array.size(); i++) {
                 PdfObject o = array.getPdfObject(i);
-                if (o instanceof PdfIndirectReference) {
+                if (o != null && o.type() == 0) {
                     for (PdfIndirectObject entry : unmergedSet) {
-                        if (entry.getIndirectReference().toString().equals(o.toString())) {
+                        if (entry.getIndirectReference().getNumber() == ((PdfIndirectReference)o).getNumber() &&
+                                entry.getIndirectReference().getGeneration() == ((PdfIndirectReference)o).getGeneration()) {
                             if (entry.object.isDictionary()) {
                                 PdfNumber annotId = ((PdfDictionary)entry.object).getAsNumber(PdfCopy.annotId);
                                 if (annotId != null) {
@@ -1120,9 +1231,10 @@ public class PdfCopy extends PdfWriter {
             PdfDictionary dictionary = (PdfDictionary)obj;
             for (PdfName key : dictionary.getKeys()) {
                 PdfObject o = dictionary.get(key);
-                if (o instanceof PdfIndirectReference) {
+                if (o != null && o.type() == 0) {
                     for (PdfIndirectObject entry : unmergedSet) {
-                        if (entry.getIndirectReference().toString().equals(o.toString())) {
+                        if (entry.getIndirectReference().getNumber() == ((PdfIndirectReference)o).getNumber() &&
+                                entry.getIndirectReference().getGeneration() == ((PdfIndirectReference)o).getGeneration()) {
                             if (entry.object.isDictionary()) {
                                 PdfNumber annotId = ((PdfDictionary)entry.object).getAsNumber(PdfCopy.annotId);
                                 if (annotId != null) {
@@ -1187,9 +1299,11 @@ public class PdfCopy extends PdfWriter {
         for (int k = 0; k < fields.size(); ++k) {
             AcroFields af = fields.get(k);
             Map<String, AcroFields.Item> fd = af.getFields();
-            addPageOffsetToField(fd, pageOffset);
+            if (pageOffset < importedPages.size() && importedPages.get(pageOffset).reader == af.reader) {
+                addPageOffsetToField(fd, pageOffset);
+                pageOffset += af.reader.getNumberOfPages();
+            }
             mergeWithMaster(fd);
-            pageOffset += af.reader.getNumberOfPages();
         }
     }
 
@@ -1323,8 +1437,14 @@ public class PdfCopy extends PdfWriter {
     }
 
     private void createAcroForms() throws IOException, BadPdfFormatException {
-        if (fieldTree.isEmpty())
+        if (fieldTree.isEmpty()) {
+            //write annotations that appear just at page level (comments, popups)
+            for (ImportedPage importedPage : importedPages) {
+                if (importedPage.mergedFields.size() > 0)
+                    addToBody(importedPage.mergedFields, importedPage.annotsIndirectReference);
+            }
             return;
+        }
         PdfDictionary form = new PdfDictionary();
         form.put(PdfName.DR, propagate(resources));
 
@@ -1346,6 +1466,9 @@ public class PdfCopy extends PdfWriter {
         if (co.size() > 0)
             form.put(PdfName.CO, co);
         this.acroForm = addToBody(form).getIndirectReference();
+        for (ImportedPage importedPage : importedPages) {
+            addToBody(importedPage.mergedFields, importedPage.annotsIndirectReference);
+        }
     }
 
     private void updateReferences(PdfObject obj) {
@@ -1413,8 +1536,7 @@ public class PdfCopy extends PdfWriter {
                     dic.remove(iTextTag);
                     dic.put(PdfName.TYPE, PdfName.ANNOT);
                     adjustTabOrder(annots, ind, nn);
-                }
-                else {
+                } else {
                     PdfDictionary field = (PdfDictionary)list.get(0);
                     PdfArray kids = new PdfArray();
                     for (int k = 1; k < list.size(); k += 2) {
@@ -1427,13 +1549,24 @@ public class PdfCopy extends PdfWriter {
                         widget.remove(iTextTag);
                         if (PdfCopy.isTextField(field)) {
                             PdfString v = field.getAsString(PdfName.V);
-                            PdfObject ap = widget.get(PdfName.AP);
+                            PdfObject ap = widget.getDirectObject(PdfName.AP);
                             if (v != null && ap != null) {
                                 if (!mergedTextFields.containsKey(list)) {
-                                    mergedTextFields.put(list, ap);
+                                    mergedTextFields.put(list, v);
                                 } else {
-                                    PdfObject ap1 = mergedTextFields.get(list);
-                                    widget.put(PdfName.AP, copyObject(ap1));
+                                    try {
+                                        TextField tx = new TextField(this, null, null);
+                                        fields.get(0).decodeGenericDictionary(widget, tx);
+                                        Rectangle box = PdfReader.getNormalizedRectangle(widget.getAsArray(PdfName.RECT));
+                                        if (tx.getRotation() == 90 || tx.getRotation() == 270)
+                                            box = box.rotate();
+                                        tx.setBox(box);
+                                        tx.setText(mergedTextFields.get(list).toUnicodeString());
+                                        PdfAppearance app = tx.getAppearance();
+                                        ((PdfDictionary)ap).put(PdfName.N, app.getIndirectReference());
+                                    } catch (DocumentException e) {
+                                        //do nothing
+                                    }
                                 }
                             }
                         } else if (PdfCopy.isCheckButton(field)) {
@@ -1460,7 +1593,7 @@ public class PdfCopy extends PdfWriter {
                     }
                     dic.put(PdfName.KIDS, kids);
                 }
-                    arr.add(ind);
+                arr.add(ind);
                 addToBody(dic, ind, true);
             }
         }
@@ -1576,7 +1709,7 @@ public class PdfCopy extends PdfWriter {
         if (open) {
             pdf.close();
             super.close();
-// Users are responsible for closing PdfReaderw            
+//  Users are responsible for closing PdfReader
 //            if (ri != null) {
 //                try {
 //                    ri.getReader().close();
@@ -1588,19 +1721,24 @@ public class PdfCopy extends PdfWriter {
 //            }
         }
     }
+
     public PdfIndirectReference add(PdfOutline outline) { return null; }
+
     @Override
     public void addAnnotation(PdfAnnotation annot) {  }
+
     @Override
     PdfIndirectReference add(PdfPage page, PdfContents contents) throws PdfException { return null; }
 
     @Override
     public void freeReader(PdfReader reader) throws IOException {
+        if (mergeFields)
+            throw new UnsupportedOperationException(MessageLocalization.getComposedMessage("it.is.not.possible.to.free.reader.in.merge.fields.mode"));
     	PdfArray array = reader.trailer.getAsArray(PdfName.ID);
     	if (array != null)
     		originalFileID = array.getAsString(0).getBytes();
         indirectMap.remove(reader);
-// TODO: Removed - the user should be responsible for closing all PdfReaders.  But, this could cause a lot of memory leaks in code out there that hasn't been properly closing things - maybe add a finalizer to PdfReader that calls PdfReader#close() ??            	
+//  TODO: Removed - the user should be responsible for closing all PdfReaders.  But, this could cause a lot of memory leaks in code out there that hasn't been properly closing things - maybe add a finalizer to PdfReader that calls PdfReader#close() ??
 //        if (currentPdfReaderInstance != null) {
 //            if (currentPdfReaderInstance.getReader() == reader) {
 //                try {
@@ -1712,6 +1850,8 @@ public class PdfCopy extends PdfWriter {
     public PageStamp createPageStamp(PdfImportedPage iPage) {
         int pageNum = iPage.getPageNumber();
         PdfReader reader = iPage.getPdfReaderInstance().getReader();
+        if (isTagged())
+            throw new RuntimeException(MessageLocalization.getComposedMessage("creating.page.stamp.not.allowed.for.tagged.reader"));
         PdfDictionary pageN = reader.getPageN(pageNum);
         return new PageStamp(reader, pageN, this);
     }
