@@ -1,16 +1,17 @@
 /*
- * $Id: PdfCopyFieldsImp.java 5979 2013-08-30 13:47:59Z achingarev $
+ * $Id: PdfCopyFieldsImp.java 6145 2014-01-14 12:57:15Z achingarev $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -45,12 +46,7 @@ package com.itextpdf.text.pdf;
 
 import java.io.IOException;
 import java.io.OutputStream;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.StringTokenizer;
+import java.util.*;
 
 import com.itextpdf.text.Document;
 import com.itextpdf.text.DocumentException;
@@ -88,6 +84,9 @@ class PdfCopyFieldsImp extends PdfWriter {
     private ArrayList<Object> calculationOrderRefs;
     private boolean hasSignature;
     private boolean needAppearances = false;
+    private HashSet<Object> mergedRadioButtons = new HashSet<Object>();
+
+
 
     protected Counter COUNTER = CounterFactory.getCounter(PdfCopyFields.class);
     protected Counter getCounter() {
@@ -312,6 +311,8 @@ class PdfCopyFieldsImp extends PdfWriter {
                     adjustTabOrder(annots, ind, nn);
                 }
                 else {
+                    PdfDictionary field = (PdfDictionary)list.get(0);
+                    PdfName v = field.getAsName(PdfName.V);
                     PdfArray kids = new PdfArray();
                     for (int k = 1; k < list.size(); k += 2) {
                         int page = ((Integer)list.get(k)).intValue();
@@ -326,6 +327,21 @@ class PdfCopyFieldsImp extends PdfWriter {
                         widget.put(PdfName.PARENT, ind);
                         PdfNumber nn = (PdfNumber)widget.get(iTextTag);
                         widget.remove(iTextTag);
+                        if (PdfCopy.isCheckButton(field)) {
+                            PdfName as = widget.getAsName(PdfName.AS);
+                            if (v != null && as != null)
+                                widget.put(PdfName.AS, v);
+                        } else if (PdfCopy.isRadioButton(field)) {
+                            PdfName as = widget.getAsName(PdfName.AS);
+                            if (v != null && as != null && !as.equals(getOffStateName(widget))) {
+                                if (!mergedRadioButtons.contains(list)) {
+                                    mergedRadioButtons.add(list);
+                                    widget.put(PdfName.AS, v);
+                                } else {
+                                    widget.put(PdfName.AS, getOffStateName(widget));
+                                }
+                            }
+                        }
                         PdfIndirectReference wref = addToBody(widget).getIndirectReference();
                         adjustTabOrder(annots, wref, nn);
                         kids.add(wref);
@@ -341,6 +357,10 @@ class PdfCopyFieldsImp extends PdfWriter {
         return arr;
     }
 
+    protected PdfName getOffStateName(PdfDictionary widget) {
+        return PdfName.Off;
+    }
+
     protected void createAcroForms() throws IOException {
         if (fieldTree.isEmpty())
             return;
