@@ -1,16 +1,17 @@
 /*
- * $Id: PdfDiv.java 6022 2013-09-26 11:08:54Z eugenemark $
+ * $Id: PdfDiv.java 6192 2014-01-29 14:37:53Z eugenemark $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -456,7 +457,10 @@ public class PdfDiv implements Element, Spaceable, IAccessibleElement {
                 if (backgroundWidth > 0 && backgroundHeight > 0) {
                     Rectangle background = new Rectangle(leftX, maxY - backgroundHeight, leftX + backgroundWidth, maxY);
                     background.setBackgroundColor(backgroundColor);
+                    PdfArtifact artifact = new PdfArtifact();
+                    canvas.openMCBlock(artifact);
                     canvas.rectangle(background);
+                    canvas.closeMCBlock(artifact);
                 }
             }
         }
@@ -540,4 +544,7 @@ public class PdfDiv implements Element, Spaceable, IAccessibleElement {
         this.id = id;
     }
 
+    public boolean isInline() {
+        return false;
+    }
 }
