@@ -1,16 +1,17 @@
 /*
- * $Id: PdfFileSpecification.java 6060 2013-11-06 14:07:28Z pavel-alay $
+ * $Id: PdfFileSpecification.java 6143 2014-01-13 14:51:08Z pavel-alay $
  *
  * This file is part of the iText (R) project.
- * Copyright (c) 1998-2013 1T3XT BVBA
+ * Copyright (c) 1998-2014 iText Group NV
  * Authors: Bruno Lowagie, Paulo Soares, et al.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3
  * as published by the Free Software Foundation with the addition of the
  * following permission added to Section 15 as permitted in Section 7(a):
- * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
- * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
+ * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
+ * ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
+ * OF THIRD PARTY RIGHTS
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -202,12 +203,13 @@ public class PdfFileSpecification extends PdfDictionary {
             if (!param.contains(PdfName.MODDATE)) {
                 param.put(PdfName.MODDATE, new PdfDate());
             }
-            if (fileStore != null) {
+            if (fileStore == null) {
+                stream.put(PdfName.PARAMS, refFileLength);
+            }
+            else {
                 param.put(PdfName.SIZE, new PdfNumber(stream.getRawLength()));
                 stream.put(PdfName.PARAMS, param);
             }
-            else
-                stream.put(PdfName.PARAMS, refFileLength);
 
             if (mimeType != null)
                 stream.put(PdfName.SUBTYPE, new PdfName(mimeType));
