@@ -1,5 +1,5 @@
 /*
- * $Id: PdfLine.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: PdfLine.java 6464 2014-07-10 15:25:20Z eugenemark $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -164,33 +164,38 @@ public class PdfLine {
                     tabStopAnchorPosition = Float.NaN;
                     tabStop = PdfChunk.getTabStop(chunk, originalWidth - width);
                     if (tabStop.getPosition() > originalWidth) {
-                        width = 0;
                         if (isWhiteSpace)
-                            return null;
-                        else
-                            return chunk;
+                            overflow = null;
+                        else if (Math.abs(originalWidth - width) < 0.001) {
+                            addToLine(chunk);
+                            overflow = null;
+                        } else {
+                            overflow = chunk;
+                        }
+                        width = 0;
+                    } else {
+                        chunk.setTabStop(tabStop);
+                        if (tabStop.getAlignment() == TabStop.Alignment.LEFT) {
+                            width = originalWidth - tabStop.getPosition();
+                            tabStop = null;
+                            tabPosition = Float.NaN;
+                        } else
+                            tabPosition = originalWidth - width;
+                        addToLine(chunk);
                     }
-                    tabStop.setPosition(tabStop.getPosition());
-                    chunk.setTabStop(tabStop);
-                    if (tabStop.getAlignment() == TabStop.Alignment.LEFT) {
-                        width = originalWidth - tabStop.getPosition();
-                        tabStop = null;
-                        tabPosition = Float.NaN;
-                    } else
-                        tabPosition = originalWidth - width;
                 } else
                     return null;
             } else {
                 //Keep deprecated tab logic for backward compatibility...
                 Float tabStopPosition = ((Float)tab[1]).floatValue();
                 boolean newline = ((Boolean)tab[2]).booleanValue();
-                if (newline && tabPosition < originalWidth - width) {
+                if (newline && tabStopPosition < originalWidth - width) {
                     return chunk;
                 }
                 chunk.adjustLeft(left);
                 width = originalWidth - tabStopPosition;
+                addToLine(chunk);
             }
-            addToLine(chunk);
         }
         // if the length of the chunk > 0 we add it to the line
         else if (chunk.length() > 0 || chunk.isImage()) {
