@@ -1,5 +1,5 @@
 /*
- * $Id: PdfName.java 6229 2014-02-11 11:27:04Z michaeldemey $
+ * $Id: PdfName.java 6511 2014-08-26 13:35:39Z achingarev $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -131,6 +131,11 @@ public class
     public static final PdfName AESV2 = new PdfName("AESV2");
     /** A name */
     public static final PdfName AESV3 = new PdfName("AESV3");
+    /**
+     * A name
+     * @since 5.5.2
+     */
+    public static final PdfName AF = new PdfName("AF");
     /**
      * A name
      * @since 5.4.5
@@ -408,6 +413,7 @@ public class
      * @since 5.3.4
      */
     public static final PdfName COLOR = new PdfName("Color");
+    public static final PdfName COLORANTS = new PdfName("Colorants");
     /** A name */
     public static final PdfName COLORS = new PdfName("Colors");
     /** A name */
@@ -1020,6 +1026,11 @@ public class
     public static final PdfName IDENTITY = new PdfName("Identity");
     /** A name */
     public static final PdfName IF = new PdfName("IF");
+    /**
+     * A name
+     * @since 5.5.3
+     */
+    public static final PdfName IM = new PdfName("IM");
     /** A name */
     public static final PdfName IMAGE = new PdfName("Image");
     /** A name */
@@ -1292,6 +1303,7 @@ public class
      * @since 2.1.6
      */
     public static final PdfName NAVIGATIONPANE = new PdfName("NavigationPane");
+    public static final PdfName NCHANNEL = new PdfName("NChannel");
     /**
      * A name.
      * @since 2.1.6
@@ -1530,7 +1542,7 @@ public class
      * A name.
      * @since 5.0.2
      */
-    public static final PdfName POLYLINE = new PdfName("Polyline");
+    public static final PdfName POLYLINE = new PdfName("PolyLine");
     /** A name */
     public static final PdfName POPUP = new PdfName("Popup");
     /**
@@ -1885,6 +1897,8 @@ public class
     /** A name */
     public static final PdfName STAMP = new PdfName("Stamp");
     /** A name */
+    public static final PdfName STATUS = new PdfName("Status");
+    /** A name */
     public static final PdfName STANDARD = new PdfName("Standard");
     /**
      * A name
