@@ -1,5 +1,5 @@
 /*
- * $Id: PdfSpotColor.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: PdfSpotColor.java 6379 2014-05-16 10:12:59Z eugenemark $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -53,7 +53,7 @@ import com.itextpdf.text.error_messages.MessageLocalization;
  * @see		PdfDictionary
  */
 
-public class PdfSpotColor{
+public class PdfSpotColor implements ICachedColorSpace, IPdfSpecialColorSpace {
     
 /**	The color name */
     public PdfName name;
@@ -61,6 +61,8 @@ public class PdfSpotColor{
 /** The alternative color space */
     public BaseColor altcs;
     // constructors
+
+    public ColorDetails altColorDetails;
     
     /**
      * Constructs a new <CODE>PdfSpotColor</CODE>.
@@ -73,6 +75,13 @@ public class PdfSpotColor{
         this.name = new PdfName(name);
         this.altcs = altcs;
     }
+
+    public ColorDetails[] getColorantDetails(PdfWriter writer) {
+        if (altColorDetails == null && this.altcs instanceof ExtendedColor && ((ExtendedColor) this.altcs).getType() == ExtendedColor.TYPE_LAB) {
+            altColorDetails = writer.addSimple(((LabColor)altcs).getLabColorSpace());
+        }
+        return new ColorDetails[] {altColorDetails};
+    }
     
     /**
      * Gets the alternative ColorSpace.
@@ -81,8 +90,18 @@ public class PdfSpotColor{
     public BaseColor getAlternativeCS() {
         return altcs;
     }
-    
+
+    public PdfName getName() {
+        return name;
+    }
+
+
+    @Deprecated
     protected PdfObject getSpotObject(PdfWriter writer) {
+        return getPdfObject(writer);
+    }
+
+    public PdfObject getPdfObject(PdfWriter writer) {
         PdfArray array = new PdfArray(PdfName.SEPARATION);
         array.add(name);
         PdfFunction func = null;
@@ -91,7 +110,7 @@ public class PdfSpotColor{
             switch (type) {
                 case ExtendedColor.TYPE_GRAY:
                     array.add(PdfName.DEVICEGRAY);
-                    func = PdfFunction.type2(writer, new float[]{0, 1}, null, new float[]{0}, new float[]{((GrayColor)altcs).getGray()}, 1);
+                    func = PdfFunction.type2(writer, new float[]{0, 1}, null, new float[]{1}, new float[]{((GrayColor)altcs).getGray()}, 1);
                     break;
                 case ExtendedColor.TYPE_CMYK:
                     array.add(PdfName.DEVICECMYK);
@@ -99,6 +118,15 @@ public class PdfSpotColor{
                     func = PdfFunction.type2(writer, new float[]{0, 1}, null, new float[]{0, 0, 0, 0},
                         new float[]{cmyk.getCyan(), cmyk.getMagenta(), cmyk.getYellow(), cmyk.getBlack()}, 1);
                     break;
+                case ExtendedColor.TYPE_LAB:
+                    LabColor lab = (LabColor)altcs;
+                    if (altColorDetails != null)
+                        array.add(altColorDetails.getIndirectReference());
+                    else
+                        array.add(lab.getLabColorSpace().getPdfObject(writer));
+                    func = PdfFunction.type2(writer, new float[]{0, 1}, null, new float[]{100f, 0f, 0f},
+                            new float[]{lab.getL(), lab.getA(), lab.getB()}, 1);
+                    break;
                 default:
                     throw new RuntimeException(MessageLocalization.getComposedMessage("only.rgb.gray.and.cmyk.are.supported.as.alternative.color.spaces"));
             }
@@ -112,8 +140,23 @@ public class PdfSpotColor{
         return array;
     }
 
-    public boolean equals(Object obj) {
-        return obj instanceof PdfSpotColor && ((PdfSpotColor)obj).name == this.name && ((PdfSpotColor)obj).altcs == this.altcs;
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) return true;
+        if (!(o instanceof PdfSpotColor)) return false;
+
+        PdfSpotColor spotColor = (PdfSpotColor) o;
+
+        if (!altcs.equals(spotColor.altcs)) return false;
+        if (!name.equals(spotColor.name)) return false;
+
+        return true;
     }
 
+    @Override
+    public int hashCode() {
+        int result = name.hashCode();
+        result = 31 * result + altcs.hashCode();
+        return result;
+    }
 }
