@@ -1,5 +1,5 @@
 /*
- * $Id: PdfStamper.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: PdfStamper.java 6543 2014-09-08 12:59:11Z michaeldemey $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -44,15 +44,6 @@
  */
 package com.itextpdf.text.pdf;
 
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.OutputStream;
-import java.security.cert.Certificate;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
 import com.itextpdf.text.DocWriter;
 import com.itextpdf.text.DocumentException;
 import com.itextpdf.text.Image;
@@ -64,6 +55,15 @@ import com.itextpdf.text.pdf.interfaces.PdfViewerPreferences;
 import com.itextpdf.text.pdf.security.LtvVerification;
 import com.itextpdf.text.xml.xmp.XmpWriter;
 
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.security.cert.Certificate;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 /** Applies extra content to the pages of a PDF document.
  * This extra content can be all the objects allowed in PdfContentByte
  * including pages from other Pdfs. The original PDF will keep
@@ -395,6 +395,15 @@ public class PdfStamper
     	stamper.setFreeTextFlattening(flat);
 	}
 
+    /**
+     * Flatten annotations with an appearance stream on close().
+     *
+     * @param flat boolean to indicate whether iText should flatten annotations or not.
+     */
+    public void setAnnotationFlattening(final boolean flat) {
+        stamper.setFlatAnnotations(flat);
+    }
+
     /**
      * Adds an annotation of form field in a specific page. This page number
      * can be overridden with {@link PdfAnnotation#setPlaceInPage(int)}.
@@ -476,6 +485,15 @@ public class PdfStamper
         stamper.addJavaScript(js, !PdfEncodings.isPdfDocEncoding(js));
     }
 
+    /** Adds a JavaScript action at the document level. When the document
+     * opens all this JavaScript runs. The existing JavaScript will be replaced.
+     * @param name the name for the JavaScript snippet in the name tree
+     * @param js the JavaScript code
+     */
+    public void addJavaScript(final String name, final String js) {
+        stamper.addJavaScript(name, PdfAction.javaScript(js, stamper, !PdfEncodings.isPdfDocEncoding(js)));
+    }
+
     /** Adds a file attachment at the document level. Existing attachments will be kept.
      * @param description the file description
      * @param fileStore an array with the file. If it's <CODE>null</CODE>
