@@ -1,5 +1,5 @@
 /*
- * $Id: TaggedPdfReaderTool.java 6134 2013-12-23 13:15:14Z blowagie $
+ * $Id: TaggedPdfReaderTool.java 6371 2014-05-14 11:05:29Z pavel-alay $
  *
  * This file is part of the iText (R) project.
  * Copyright (c) 1998-2014 iText Group NV
@@ -44,20 +44,14 @@
  */
 package com.itextpdf.text.pdf.parser;
 
+import com.itextpdf.text.error_messages.MessageLocalization;
+import com.itextpdf.text.pdf.*;
+import com.itextpdf.text.xml.XMLUtil;
+
 import java.io.IOException;
 import java.io.OutputStream;
-import java.io.PrintWriter;
-
-import com.itextpdf.text.error_messages.MessageLocalization;
-import com.itextpdf.text.pdf.PdfArray;
-import com.itextpdf.text.pdf.PdfDictionary;
-import com.itextpdf.text.pdf.PdfName;
-import com.itextpdf.text.pdf.PdfNumber;
-import com.itextpdf.text.pdf.PdfObject;
-import com.itextpdf.text.pdf.PdfReader;
-import com.itextpdf.text.xml.XMLUtil;
 import java.io.OutputStreamWriter;
-import java.nio.charset.Charset;
+import java.io.PrintWriter;
 import java.util.Set;
 
 /**
@@ -110,7 +104,7 @@ public class TaggedPdfReaderTool {
 	 */
 	public void convertToXml(PdfReader reader, OutputStream os)
 			throws IOException {
-        convertToXml(reader, os, Charset.defaultCharset().name());
+        convertToXml(reader, os, "UTF-8");
     }
 
     /**
@@ -189,6 +183,12 @@ public class TaggedPdfReaderTool {
                 }
             }
             out.print(">");
+            PdfObject alt = k.get(PdfName.ALT);
+            if (alt != null && alt.toString() != null) {
+                out.print("<alt><![CDATA[");
+                out.print(alt.toString().replaceAll("[\\000]*", ""));
+                out.print("]]></alt>");
+            }
             PdfDictionary dict = k.getAsDict(PdfName.PG);
             if (dict != null)
                 parseTag(tagN, k.getDirectObject(PdfName.K), dict);
